@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2006 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006 John Tapsell <johnflux@gmail.com>
+    SPDX-FileCopyrightText: 2006 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006 John Tapsell <johnflux@gmail.com>
 */
 
 #ifndef ALIAS_CONFIG_H
@@ -22,8 +17,8 @@ class Alias_Config : public QWidget, public KonviSettingsPage, private Ui::Alias
     Q_OBJECT
 
     public:
-        explicit Alias_Config(QWidget* parent, const char* name = 0);
-        ~Alias_Config() override;
+        explicit Alias_Config(QWidget* parent, const char* name = nullptr);
+        ~Alias_Config();
 
         void saveSettings() override;
         void loadSettings() override;
@@ -33,20 +28,22 @@ class Alias_Config : public QWidget, public KonviSettingsPage, private Ui::Alias
     Q_SIGNALS:
         void modified();
 
-    protected Q_SLOTS:
+    private Q_SLOTS:
         void entrySelected(QTreeWidgetItem* aliasEntry);
         void nameChanged(const QString& newName);
         void actionChanged(const QString& newAction);
         void addEntry();
         void removeEntry();
 
-    protected:
+    private:
         void setAliasListView(const QStringList& aliasList);
+        QStringList currentAliasList() const;
 
+    private:
         bool m_newItemSelected;
-
         QStringList m_oldAliasList;
-        QStringList currentAliasList();
+
+        Q_DISABLE_COPY(Alias_Config)
 };
 
 #endif
