@@ -1,15 +1,7 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Nick Information
-  begin:     Sat Jan 17 2004
-  copyright: (C) 2004 by Gary Cramblitt
-  email:     garycramblitt@comcast.net
+    SPDX-FileCopyrightText: 2004 Gary Cramblitt <garycramblitt@comcast.net>
 */
 
 #ifndef NICKINFO_H
@@ -51,7 +43,7 @@ class NickInfo : public QSharedData
         QString getNetServer() const;
         QString getNetServerInfo() const;
         QDateTime getOnlineSince() const;
-        uint getNickColor();
+        uint getNickColor() const;
         /** Whether this user is identified with nickserv.
          *  Found only by doing /whois nick
          */
@@ -101,10 +93,10 @@ class NickInfo : public QSharedData
          *
          *  @return A string to show the user for the name of this contact
          */
-        QString getBestAddresseeName();
+        QString getBestAddresseeName() const;
 
         void setPrintedOnline(bool printed);
-        bool getPrintedOnline();
+        bool getPrintedOnline() const;
 
         QString account() const { return m_account; }
         void setAccount(const QString &name);
@@ -136,11 +128,13 @@ class NickInfo : public QSharedData
         bool m_printedOnline;
         /* The color index for lookup on Preferences::NickColor(index).name()
            Internally stored as index-1 to allow checking for 0 */
-        uint m_nickColor;
+        mutable uint m_nickColor;
 
         QString m_account;
 
         bool m_changed;
+
+        Q_DISABLE_COPY(NickInfo)
 };
 
 /** A NickInfoPtr is a pointer to a NickInfo object.  Since it is a QExplicitlySharedDataPointer, the NickInfo
