@@ -1,14 +1,9 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+    SPDX-License-Identifier: GPL-2.0-or-later
+
+    SPDX-FileCopyrightText: 2004 Peter Simonsson <psn@linux.se>
 */
 
-/*
-  copyright: (C) 2004 by Peter Simonsson
-  email:     psn@linux.se
-*/
 #ifndef KONVERSATIONNOTIFICATIONHANDLER_H
 #define KONVERSATIONNOTIFICATIONHANDLER_H
 
@@ -29,8 +24,8 @@ namespace Konversation
         Q_OBJECT
 
         public:
-            explicit NotificationHandler(Application* parent = 0);
-            ~NotificationHandler() override;
+            explicit NotificationHandler(Application* parent = nullptr);
+            ~NotificationHandler();
 
         public Q_SLOTS:
             void message(ChatWindow* chatWin, const QString& fromNick, const QString& message);
@@ -53,11 +48,13 @@ namespace Konversation
             void connectionFailure(ChatWindow* chatWin, const QString& server);
             void channelJoin(ChatWindow* chatWin, const QString& channel);
 
-        protected:
+        private:
             void startTrayNotification(ChatWindow* chatWin);
 
         private:
             MainWindow* m_mainWindow;
+
+            Q_DISABLE_COPY(NotificationHandler)
     };
 
 }
