@@ -1,13 +1,8 @@
 /*
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-*/
+    SPDX-License-Identifier: GPL-2.0-or-later
 
-/*
-  Copyright (C) 2003 Dario Abatianni <eisfuchs@tigress.com>
-  Copyright (C) 2006-2008 Eike Hein <hein@kde.org>
+    SPDX-FileCopyrightText: 2003 Dario Abatianni <eisfuchs@tigress.com>
+    SPDX-FileCopyrightText: 2006-2008 Eike Hein <hein@kde.org>
 */
 
 #include "statuspanel.h"
@@ -19,9 +14,9 @@
 #include "server.h"
 
 #include <KComboBox>
-#include <KLineEdit>
 #include <KMessageBox>
 
+#include <QLineEdit>
 #include <QHBoxLayout>
 
 using namespace Konversation;
@@ -42,14 +37,14 @@ StatusPanel::StatusPanel(QWidget* parent) : ChatWindow(parent)
     QWidget* commandLineBox=new QWidget(this);
     QHBoxLayout* commandLineBoxLayout = new QHBoxLayout(commandLineBox);
     commandLineBoxLayout->setSpacing(spacing());
-    commandLineBoxLayout->setMargin(0);
+    commandLineBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     nicknameCombobox = new KComboBox(commandLineBox);
     commandLineBoxLayout->addWidget(nicknameCombobox);
     nicknameCombobox->setEditable(true);
     nicknameCombobox->setSizeAdjustPolicy(KComboBox::AdjustToContents);
-    KLineEdit* nicknameComboboxLineEdit = qobject_cast<KLineEdit*>(nicknameCombobox->lineEdit());
-    if (nicknameComboboxLineEdit) nicknameComboboxLineEdit->setClearButtonShown(false);
+    QLineEdit* nicknameComboboxLineEdit = nicknameCombobox->lineEdit();
+    nicknameComboboxLineEdit->setClearButtonEnabled(false);
     nicknameCombobox->setWhatsThis(i18n("<qt><p>This shows your current nick, and any alternatives you have set up.  If you select or type in a different nickname, then a request will be sent to the IRC server to change your nick.  If the server allows it, the new nickname will be selected.  If you type in a new nickname, you need to press 'Enter' at the end.</p><p>You can edit the alternative nicknames from the <em>Identities</em> option in the <em>Settings</em> menu.</p></qt>"));
 
     awayLabel=new AwayLabel(commandLineBox);
@@ -62,19 +57,21 @@ StatusPanel::StatusPanel(QWidget* parent) : ChatWindow(parent)
     getTextView()->installEventFilter(m_inputBar);
     m_inputBar->installEventFilter(this);
 
-    connect(getTextView(),SIGNAL (gotFocus()),m_inputBar,SLOT (setFocus()) );
+    connect(getTextView(), &IRCView::gotFocus, m_inputBar, QOverload<>::of(&IRCInput::setFocus));
 
-    connect(getTextView(),SIGNAL (sendFile()),this,SLOT (sendFileMenu()) );
-    connect(getTextView(),SIGNAL (autoText(QString)),this,SLOT (sendText(QString)) );
+    connect(getTextView(),&IRCView::sendFile,this,&StatusPanel::sendFileMenu );
+    connect(getTextView(), &IRCView::autoText, this, &StatusPanel::sendText);
 
     connect(m_inputBar, &IRCInput::submit, this, &StatusPanel::statusTextEntered);
     connect(m_inputBar, &IRCInput::textPasted, this, &StatusPanel::textPasted);
-    connect(getTextView(), SIGNAL(textPasted(bool)), m_inputBar, SLOT(paste(bool)));
+    connect(getTextView(), &IRCView::textPasted, m_inputBar, &IRCInput::paste);
 
-    connect(nicknameCombobox, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &StatusPanel::nicknameComboboxChanged);
+    connect(nicknameCombobox, QOverload<int>::of(&KComboBox::activated),
+            this, &StatusPanel::nicknameComboboxChanged);
     Q_ASSERT(nicknameCombobox->lineEdit());       //it should be editable.  if we design it so it isn't, remove these lines.
     if(nicknameCombobox->lineEdit())
-        connect(nicknameCombobox->lineEdit(), SIGNAL (editingFinished()),this,SLOT(nicknameComboboxChanged()));
+        connect(nicknameCombobox->lineEdit(), &QLineEdit::editingFinished,
+                this, &StatusPanel::nicknameComboboxChanged);
 
     updateAppearance();
 }
@@ -104,14 +101,11 @@ void StatusPanel::sendText(const QString& sendLine)
     QString outputAll(sendLine);
 
     // replace aliases and wildcards
-    m_server->getOutputFilter()->replaceAliases(outputAll, this);
+    OutputFilter::replaceAliases(outputAll, this);
 
     // Send all strings, one after another
-    QStringList outList=outputAll.split('\n');
-    for(int index=0;index<outList.count();index++)
-    {
-        QString output(outList[index]);
-
+    const QStringList outList = outputAll.split(QLatin1Char('\n'));
+    for (const QString& output : outList) {
         // encoding stuff is done in Server()
         Konversation::OutputFilterResult result = m_server->getOutputFilter()->parse(m_server->getNickname(), output, QString(), this);
 
@@ -137,10 +131,8 @@ void StatusPanel::textPasted(const QString& text)
 {
     if(m_server)
     {
-        QStringList multiline=text.split('\n');
-        for(int index=0;index<multiline.count();index++)
-        {
-            QString line=multiline[index];
+        const QStringList multiline = text.split(QLatin1Char('\n'));
+        for (QString line : multiline) {
             QString cChar(Preferences::self()->commandChar());
             // make sure that lines starting with command char get escaped
             if(line.startsWith(cChar)) line=cChar+line;
@@ -212,8 +204,8 @@ void StatusPanel::showEvent(QShowEvent*)
     }
 }
 
-bool StatusPanel::canBeFrontView()        { return true; }
-bool StatusPanel::searchView()       { return true; }
+bool StatusPanel::canBeFrontView() const  { return true; }
+bool StatusPanel::searchView() const      { return true; }
 
 void StatusPanel::setNotificationsEnabled(bool enable)
 {
@@ -234,7 +226,7 @@ bool StatusPanel::closeYourself(bool confirm)
                 i18n("Close Tab"),
                 KStandardGuiItem::close(),
                 KStandardGuiItem::cancel(),
-                "QuitServerTab");
+                QStringLiteral("QuitServerTab"));
     }
     else
     {
@@ -244,7 +236,7 @@ bool StatusPanel::closeYourself(bool confirm)
             i18n("Disconnect From Server"),
             KGuiItem(i18n("Disconnect")),
             KStandardGuiItem::cancel(),
-            "QuitServerTab");
+            QStringLiteral("QuitServerTab"));
     }
 
     if (result==KMessageBox::Continue)
@@ -253,7 +245,7 @@ bool StatusPanel::closeYourself(bool confirm)
         m_server->quitServer();
         // This will delete the status view as well.
         m_server->deleteLater();
-        m_server = 0;
+        m_server = nullptr;
         return true;
     }
     else
@@ -273,7 +265,7 @@ void StatusPanel::nicknameComboboxChanged()
     if (oldNick != newNick)
     {
         nicknameCombobox->setCurrentIndex(nicknameCombobox->findText(oldNick));
-        m_server->queue("NICK "+newNick);
+        m_server->queue(QLatin1String("NICK ") + newNick);
     }
     // return focus to input line
     m_inputBar->setFocus();
@@ -281,7 +273,7 @@ void StatusPanel::nicknameComboboxChanged()
 
 void StatusPanel::changeNickname(const QString& newNickname)
 {
-    m_server->queue("NICK "+newNickname);
+    m_server->queue(QLatin1String("NICK ") + newNickname);
 }
 
 void StatusPanel::emitUpdateInfo()
@@ -292,20 +284,20 @@ void StatusPanel::emitUpdateInfo()
 void StatusPanel::setChannelEncoding(const QString& encoding)
 {
     if(m_server->getServerGroup())
-        Preferences::setChannelEncoding(m_server->getServerGroup()->id(), ":server", encoding);
+        Preferences::setChannelEncoding(m_server->getServerGroup()->id(), QStringLiteral(":server"), encoding);
     else
-        Preferences::setChannelEncoding(m_server->getDisplayName(), ":server", encoding);
+        Preferences::setChannelEncoding(m_server->getDisplayName(), QStringLiteral(":server"), encoding);
 }
 
-QString StatusPanel::getChannelEncoding()         // virtual
+QString StatusPanel::getChannelEncoding() const        // virtual
 {
     if(m_server->getServerGroup())
-        return Preferences::channelEncoding(m_server->getServerGroup()->id(), ":server");
-    return Preferences::channelEncoding(m_server->getDisplayName(), ":server");
+        return Preferences::channelEncoding(m_server->getServerGroup()->id(), QStringLiteral(":server"));
+    return Preferences::channelEncoding(m_server->getDisplayName(), QStringLiteral(":server"));
 }
 
                                                   // virtual
-QString StatusPanel::getChannelEncodingDefaultDesc()
+QString StatusPanel::getChannelEncodingDefaultDesc() const
 {
     return i18n("Identity Default ( %1 )", getServer()->getIdentity()->getCodecName());
 }
@@ -321,8 +313,8 @@ void StatusPanel::setServer(Server* server)
 {
     ChatWindow::setServer(server);
     nicknameCombobox->setModel(m_server->nickListModel());
-    connect(awayLabel, SIGNAL(unaway()), m_server, SLOT(requestUnaway()));
-    connect(awayLabel, SIGNAL(awayMessageChanged(QString)), m_server, SLOT(requestAway(QString)));
+    connect(awayLabel, &AwayLabel::unaway, m_server, &Server::requestUnaway);
+    connect(awayLabel, &AwayLabel::awayMessageChanged, m_server, &Server::requestAway);
 }
 
 
